#
# spec file for package gcstar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gcstar
Version:        1.8.0
Release:        1.7
Summary:        Application to manage collections
License:        GPL-2.0-or-later
URL:            https://www.gcstar.org/
Source0:        https://gitlab.com/Kerenoc/GCstar/-/archive/v%{version}/GCstar-v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  fdupes
BuildRequires:  perl
BuildRequires:  update-desktop-files
BuildRequires:  perl(Cwd)
BuildRequires:  perl(Cwd)
BuildRequires:  perl(Cwd)
BuildRequires:  perl(Data::Dumper)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(Encode)
BuildRequires:  perl(Encode::Locale)
BuildRequires:  perl(Exporter)
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Copy)
BuildRequires:  perl(File::Find)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Glib::Object::Introspection)
BuildRequires:  perl(Gtk3)
BuildRequires:  perl(Gtk3::SimpleList)
BuildRequires:  perl(HTML::Entities)
BuildRequires:  perl(HTTP::Cookies::Netscape)
BuildRequires:  perl(IO::File)
BuildRequires:  perl(IO::Handle)
BuildRequires:  perl(IO::Socket)
BuildRequires:  perl(IO::Socket::INET)
BuildRequires:  perl(LWP)
BuildRequires:  perl(LWP::Protocol::https)
BuildRequires:  perl(LWP::Simple)
BuildRequires:  perl(List::Util)
BuildRequires:  perl(Net::SMTP)
BuildRequires:  perl(POSIX)
BuildRequires:  perl(POSIX)
BuildRequires:  perl(Storable)
BuildRequires:  perl(Text::Wrap)
BuildRequires:  perl(URI::Escape)
BuildRequires:  perl(Unicode::Normalize)
BuildRequires:  perl(XML::Parser)
BuildRequires:  perl(XML::Simple)
BuildRequires:  perl(filetest)
BuildRequires:  perl(threads)
BuildRequires:  perl(threads::shared)
BuildRequires:  typelib(GdkPixdata) = 2.0
BuildRequires:  typelib(Gtk) = 3.0
BuildArch:      noarch

# Mandatory dependencies
Requires:       perl(Cwd)
Requires:       perl(Cwd)
Requires:       perl(Cwd)
Requires:       perl(Data::Dumper)
Requires:       perl(Digest::MD5)
Requires:       perl(Encode)
Requires:       perl(Encode::Locale)
Requires:       perl(Exporter)
Requires:       perl(File::Basename)
Requires:       perl(File::Copy)
Requires:       perl(File::Find)
Requires:       perl(File::Path)
Requires:       perl(File::Path)
Requires:       perl(File::Spec)
Requires:       perl(File::Temp)
Requires:       perl(Glib::Object::Introspection)
Requires:       perl(Gtk3)
Requires:       perl(Gtk3::SimpleList)
Requires:       perl(HTML::Entities)
Requires:       perl(HTTP::Cookies::Netscape)
Requires:       perl(IO::File)
Requires:       perl(IO::Handle)
Requires:       perl(IO::Socket)
Requires:       perl(IO::Socket::INET)
Requires:       perl(LWP)
Requires:       perl(LWP::Protocol::https)
Requires:       perl(LWP::Simple)
Requires:       perl(List::Util)
Requires:       perl(Net::SMTP)
Requires:       perl(POSIX)
Requires:       perl(POSIX)
Requires:       perl(Storable)
Requires:       perl(Text::Wrap)
Requires:       perl(URI::Escape)
Requires:       perl(Unicode::Normalize)
Requires:       perl(XML::Parser)
Requires:       perl(XML::Simple)
Requires:       perl(filetest)
Requires:       perl(threads)
Requires:       perl(threads::shared)

# Optional dependencies (It's probably a good idea to figure out what can be
#                        split this between Recommends and Suggests)
Recommends:     liberation-fonts
Recommends:     perl(Archive::Tar)
Recommends:     perl(Archive::Zip)
Recommends:     perl(Compress::Zlib)
Recommends:     perl(Date::Calc)
Recommends:     perl(DateTime::Format::Strptime)
Recommends:     perl(Digest::MD5)
Recommends:     perl(GD)
Recommends:     perl(GD::Graph::area)
Recommends:     perl(GD::Graph::bars)
Recommends:     perl(GD::Graph::pie)
Recommends:     perl(GD::Text)
Recommends:     perl(Image::ExifTool)
Recommends:     perl(JSON)
Recommends:     perl(Locale::Codes)
Recommends:     perl(MIME::Base64)
Recommends:     perl(MP3::Info)
Recommends:     perl(MP3::Tag)
Recommends:     perl(Net::FreeDB)
Recommends:     perl(Ogg::Vorbis::Header::PurePerl)
Recommends:     perl(Time::Piece)

%description
GCstar is a free open source application for managing collections of
movies, books, music, etc. Detailed information on each item can be
automatically retrieved from the internet and you can store additional
data, such as the location or who you've lent it to. You may also
search and filter your collection by many criteria.

Documentation can be found at https://gcstar.gitlab.io/gcstar_docs/en/

%prep
%autosetup -n GCstar-v%{version}

%build
# Nothing to build here.

%install
pushd %{name}
./install --prefix=%{buildroot}%{_prefix}/
rm -rf %{buildroot}%{_datadir}/{mime,applications}
%define _hicolordir %{_datadir}/icons/hicolor

for icon in share/gcstar/icons/gcstar_*.png; do
  size=$(echo $icon | grep -oE '[0-9]+x[0-9]+')
  # Only install sizes that exist in hicolor
  if test -d %{_datadir}/icons/hicolor/${size}/apps; then
    installdir=%{buildroot}%{_hicolordir}/${size}/apps
    install -D -m644 ${icon} ${installdir}/gcstar.png
  fi
  if test -d %{_datadir}/icons/hicolor/${size}/mimetypes; then
    installdir="%{buildroot}%{_hicolordir}/${size}/mimetypes"
    install -D -m644 ${icon} ${installdir}/application-x-gcstar.png
  fi
done

install -D -m644 share/gcstar/icons/gcstar_scalable.svg \
  %{buildroot}%{_hicolodir}/scalable/apps/gcstar.svg
install -D -m644 share/gcstar/icons/gcstar_scalable.svg \
  %{buildroot}%{_hicolordir}/scalable/mimetypes/application-x-gcstar.svg
install -D -m644 share/applications/gcstar.xml \
  -t %{buildroot}%{_datadir}/mime/packages/
popd

mkdir -p %{buildroot}%{_datadir}/applications
%suse_update_desktop_file -N GCstar -i gcstar Database GTK
%fdupes %{buildroot}%{_datadir}

%files
%{_bindir}/gcstar
%{_prefix}/lib/gcstar/
%{_datadir}/applications/gcstar.desktop
%{_datadir}/gcstar/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/gcstar.*
%{_datadir}/icons/hicolor/*/mimetypes/application-x-gcstar.*
%{_datadir}/mime/packages/gcstar.xml
%{_mandir}/man1/gcstar.1%{?ext_man}

%changelog
* Wed Jun  7 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 1.8.0:
  + Release based on Gtk3 as the default version.
  + Many new features were introduce for the users.
  + New collections: Postcards, Gadgets and MusicCourses.
  + New plugins: Bdphile (Comics), Numista and Exonumia (Coins, FR
    and EN), AnimatorEN (Films), Amazon (Gadgets), AmazonBR
    (Books), UPCitemDB (Gagdets) and Alfred (MusicCources).
  + Plugins evolutions: JeuxVideo (Games), DVDPost (Films), IMDB
    (Films), BoardGameGeek (BoardGames), BDphile (Books), MobyGames
    (Games), Amazon (Books, Films, Games), MangaSanctuary (Comics),
    Numista, Noosfere, Discogs and Brikset.
  + Plugins unavailable because of one thing, or another: Douban
    (Films), TheLegacy (VideoGames), ComicBookDb (Comics),
    ReservoirJeux (BoardGames) and FNAC (FR).
  + Bugs fixed:
  - Errors when GCstar is used in minimum configuration (no
    optional dependencies).
  - Change dependency for Liberation font.
  - Small bugs fixes in models XML/GCM and XSD (revision 5).
  - Update XSD link in GCM models.
  - Missing name for "file size unit" field (problem in
    import/export).
  - Missing images in CSV imports.
  - Support of double or multiple lists in CSV imports (actors
    for example).
  - Default min and max values for numbers.
  - Bugs in image and text lists: sorting, columns, selections.
  - Problem in titles with articles for some languages.
  - Fix duration for extracted music.
  - Inconsistencies in images list view.
  - Remember windows size when GCstar closes.
- Replace Kerenoc/GCstar gitlab.com repo Source tag with
  GCstar/GCstar.
- Update GPL-2.0-only License tag to GPL-2.0-or-later as stated in
  the GitLab repository, as well as in and the source code comment
  headers.
- Update https://wiki.gcstar.org/en URL to https://www.gcstar.org/,
  the GCstar's home page.
- Switch typelib-1_0-GdkPixdata-2_0 and typelib-1_0-Gtk-3_0 to
  their more maintainer friendly typelib(BindingName) [= Version]
  symbol notation, being typelib(GdkPixdata) = 2.0 and typelib(Gtk)
  = 3.0, respectively.
- Switch %%setup macro to the wonderfull %%autosetup, leveraging its
  automation capabilities.
- Drop downstream gcstar-fix-desktop.patch patch. It's no longer
  necessary, since the wanted modifications can be done with the
  help of %%suse_update_desktop_file macro.
- Drop no longer needed BuildRequires on shared-mime-info. It was
  needed for updating the MIME cache, functionality that has been
  moved to the shared-mime-info package via RPM filetriggers.
- Update package dependecies, according to the installer
  instructions:
  + Demote perl(DateTime::Format::Strptime) and perl(JSON) from
    BuildRequires/Requires to Recommends. They're not mandatory,
    but optional.
  + Replace perl(GD) Recommends with perl(GD::Graph::area),
    perl(GD::Graph::bars) and perl(GD::Graph::pie).
  + Add explicit BuildRequires for the following Perl modules (they
    were already being pulled): Cwd, Cwd, Cwd, Data::Dumper,
    Digest::MD5, Encode, Encode::Locale, Exporter, File::Basename,
    File::Copy, File::Find, File::Path, File::Path, File::Spec,
    File::Temp, Glib::Object::Introspection, HTML::Entities,
    HTTP::Cookies::Netscape, IO::File, IO::Handle, IO::Socket,
    IO::Socket::INET, LWP, LWP::Simple, List::Util, Net::SMTP,
    POSIX, POSIX, Storable, Text::Wrap, URI::Escape,
    Unicode::Normalize, XML::Parser, filetest, threads and
    threads::shared.
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.7.3
  * Support Gtk3
  * New features for users
  * Support for series in book collections
  * Support of original title for books
  * Identification of broken plugins (ZZZ...)
  * Max number in comics series increased to 9999999
  * Additionnal artist roles for comics (inker, letterer...)
  * Possible use of Amazon for book scanning
  * Support for TS video files (DVB recordings)
  * Memory of previous proxy setting
  * Improved default location for choosing files
  * Replacing an empty string for field will set the field if
    empty for all items of a collections (for example tags)
  * New plugins: BDphile (books), GBooks
  * User interfaces changes: Small changes in some panel layouts
  * Bugs fixed
  * Range for advanced search
  * Exportation of miniatures (jpeg, png)
  * Actors support and imags support in Tellico export
  * File extension for exporting
  * Better support of default values for fields in GCS files
  * Some bugs fixed in website plugins
  * Deprecation of plugins:
  * Alapage
  * InternetBokHandeln
  * LiberOnWeb
  * Mareno
* Mon Sep 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Adapt file list for /usr/libexec migration.
- Some spec-file cleanups:
  * Drop conditionals for EOL openSUSE versions.
  * Drop Group tag.
  * Drop unnecessary %%clean section.
  * Drop empty %%post(un) sections.
  * Remove BuildRoot tag as it is not needed any more.
  * Drop %%defattr line from file list.
* Thu Jun 30 2016 zaitor@opensuse.org
- Update to version 1.7.1:
  + New features:
  - When generating statistics, they can be grouped per dates.
  - Export to GCstar Viewer generates a collection that loads
    faster in image mode (requires GCstar Viewer 2.10 or above).
  + User interface changes:
  - Display totals for numeric fields when the list is displayed
    in detailed mode.
  + Bugs fixed:
  - User added fields were not shown in the panel below the list.
  - When exporting to HTML, it was sometimes not possible to
    select fields with the templates that support that.
  - Bugs fixed in some website plugins: Bedetheque, GameSpot,
    IMDb, jeuxvideo.com, jeuxvideo.fr, MobyGames.
  + Updated translations.
- Rebase gcstar-fix-desktop.patch.
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 1.7.0:
  + User interface changes:
  - All the settings for the current type of list can be changed
    directly below the list.
  - It's now possible to define default values for the fields
    when adding a new item to a collection.
  - New menu to show/hide menu, tool and status bars.
  - Slight animations have been added in image mode.
  - A popup is displayed in image mode to show a summary of the
    item.
  + Bugs fixed:
  - When saving an item which date is the current one.
  - The list of saved searches in toolbar was not reset when
    displaying all collection items.
  - Ranges were not handled correctly when searching.
  - With collections of video games, the units field was not
    hidden if user chose to hide file size.
  - In image mode, some items were not displayed correctly when
    grouping.
  - Fixed some website plugins.
  + Updated translations.
- Drop hack to kill backupfiles previously found in tarball. Fixed
  upstream.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Thu Jul 21 2011 vuntz@opensuse.org
- Drop perl(Switch) BuildRequires and Requires, as its usage was
  removed.
- Add perl() Recommends for optional features: Archive::Zip, GD,
  GD::Graph::area, GD::Graph::bars, GD::Graph::pie, GD::Text.
* Fri Jul 15 2011 malcolmlewis@opensuse.org
- Update to version 1.6.2:
  + Option added for sorting items while in image views.
  + Amazon book plugins now use the Amazon Web Service, for more
    reliable plugin operation.
  + New plugin for batch importing with a barcode scanner. It can
    be used with GCstar Scanner for Android or any barcode scanner
    acting like a keyboard.
  + Film collection: Country field is now a list box, allowing
    multiple countries.
  + New plugins to fetch information from websites:
  - Books: Douban (ZH) provided by BW.
  - Movies: Douban (ZH) provided by BW.
  - Music: Douban (ZH) provided by BW.
  + Various bug fixes:
  - Set focus to the title field automatically after adding an
    item.
  - Correctly handle foreign characters in external filenames
    under Windows.
  - Correctly sort numeric fields used for grouping in image
    lists.
  - It was not possible to delete a unique item in image mode.
  - Fixed bug with image caching.
  - HTTP return code 302 managed correctly.
  - Removed use of Switch.pm as it is deprecated.
  - Bug fixed in some website plugins: Alapage, Allocine,
    Bedetheque, Bol, Comic Book DB, CSFD.cz, IMDb,
    jeuxvideo.com, jeuxvideo.fr, Moby Games, The Movie DB.
- Update spec file License field from GPLv2 to GPL-2.0 to
  conform with spdx.org identifier.
* Tue May 31 2011 vuntz@opensuse.org
- Add perl(Switch) BuildRequires and Requires, as the Switch module
  got split out of the main perl package.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Remove shared-mime-info Requires: if it's not there, then we
  simply don't need to update the mime database.
* Thu Sep  2 2010 vuntz@opensuse.org
- Improve summary.
- Do not ship a modified version of gcstar.desktop. Instead, add
  gcstar-fix-desktop.patch to fix the desktop file the way we want.
- Manually install gcstar icon to hicolor, and also install it as
  the icon for the application/x-gcstar mime type. This means we
  don't need to call xdg-icon-resource in %%post (which is bad since
  it creates files).
- Use update-mime-database in %%post and %%postun. This means we
  don't need to call xdg-mime in %%post.
- Add shared-mime-info Requires(post) and Requires(postun).
- Remove xdg-utils BuildRequires and Requires(post).
- Add calls to %%icon_theme_cache_post and %%icon_theme_cache_postun.
* Fri Aug 27 2010 badshah400@gmail.com
- Update to version 1.6.1:
  + New features:
  - CSV plugin now allows you to select which field to use to
    search for internet results
  - Graphs generated from statistics are smoothed, to eliminate
    sharp lines
  + Default collections changes:
  - New default collections:
    . TV shows (series) collection model. Useful for tracking dvd
    collections of tv shows.
    . Computer Software collection
    . Video games collection: New fields: Region, Serial Number.
  + New plugins to fetch information from websites:
  - TV shows (series):
    . Thetvdb
    . Themoviedb
  + Bugs fixed:
  - Removal of more than 9 items from a collection at a time
  - Crash when trying to create a cached image from a missing
    picture, or when image does not exist
  - Some characters were incorrectly encoded in read only views
  - Add option in collection read only views for fields to
    "collapse" and hide when they have no content
  - Fixed problem at startup when some items were hidden in the
    toolbar.
  - The "View modules" menu was not working anymore.
  - Add play toolbar button for tv episodes collections.
  - Item window was not properly re-constructed after changing
    collections.
  - Dependency on Sort::Naturally removed.
  - Date::Calc module was not shown as an optional dependency
    while it is needed for statistics.
- Change perl-* dependencies to perl(*).
- Remove perl(Sort:Naturally) BuildRequires and Requires: it is no
  longer required.
- Change Name in .desktop entry to GCstar from "GCstar Collections
  Manager" (to avoid duplication with generic name)
* Thu Aug 19 2010 badshah400@gmail.com
- modify spec file to fix RPMLINT warning
- remove gtk2 from requires and buildrequires (should be
  automatically) pulled in by perl-gtk2
- add requires xdg-utils for %%post scriptlets
- corrected version tag to GPLv2 in spec file
* Wed Aug 18 2010 badshah400@gmail.com
- Include man files corectly
- Use custom .desktop file (inherited from upstream) to conform
  to openSUSE guidelines
* Sun Aug 15 2010 badshah400@gmail.com
- Use upstream provided .desktop and .xml files
* Sat Aug 14 2010 badshah400@gmail.com
- spec file cleanup
* Sat Aug  7 2010 badshah400@gmail.com
- Updated to upstream version 1.6.0
* Mon Aug  2 2010 badshah400@gmail.com
- Initial package following openSUSE Packaging Guidelines
